=== modified file 'DBUS-API'
--- DBUS-API	2011-11-26 23:08:17 +0000
+++ DBUS-API	2011-11-24 19:09:29 +0000
@@ -112,7 +112,7 @@
       Disable().
    
    f) The date and time this client will be disabled, as an RFC 3339
-      string, or an empty string if this is not scheduled.
+      string, or an empty string if this has not happened.
    
    g) The date and time of the last approval request, as an RFC 3339
       string, or an empty string if this has not happened.

=== modified file 'clients.conf'
--- clients.conf	2011-11-26 23:08:17 +0000
+++ clients.conf	2011-09-19 09:42:55 +0000
@@ -30,9 +30,6 @@
 # How long one approval will last.
 ;approval_duration = 1s
 
-# Whether this client is enabled by default
-;enabled = True
-
 
 ;####
 ;# Example client

=== modified file 'mandos'
--- mandos	2011-11-27 19:51:00 +0000
+++ mandos	2011-11-26 22:22:20 +0000
@@ -128,12 +128,11 @@
     logger.setLevel(level)
 
 
-class PGPError(Exception):
-    """Exception if encryption/decryption fails"""
+class CryptoError(Exception):
     pass
 
 
-class PGPEngine(object):
+class Crypto(object):
     """A simple class for OpenPGP symmetric encryption & decryption"""
     def __init__(self):
         self.gnupg = GnuPGInterface.GnuPG()
@@ -185,7 +184,7 @@
                     ciphertext = f.read()
                 proc.wait()
             except IOError as e:
-                raise PGPError(e)
+                raise CryptoError(e)
         self.gnupg.passphrase = None
         return ciphertext
     
@@ -202,7 +201,7 @@
                     decrypted_plaintext = f.read()
                 proc.wait()
             except IOError as e:
-                raise PGPError(e)
+                raise CryptoError(e)
         self.gnupg.passphrase = None
         return decrypted_plaintext
 
@@ -416,7 +415,7 @@
     last_checker_status: integer between 0 and 255 reflecting exit
                          status of last checker. -1 reflects crashed
                          checker, or None.
-    last_enabled: datetime.datetime(); (UTC) or None
+    last_enabled: datetime.datetime(); (UTC)
     name:       string; from the config file, used in log messages and
                         D-Bus identifiers
     secret:     bytestring; sent verbatim (over TLS) to client
@@ -474,12 +473,9 @@
                             % self.name)
         self.host = config.get("host", "")
         self.created = datetime.datetime.utcnow()
-        self.enabled = config.get("enabled", True)
+        self.enabled = True
         self.last_approval_request = None
-        if self.enabled:
-            self.last_enabled = datetime.datetime.utcnow()
-        else:
-            self.last_enabled = None
+        self.last_enabled = datetime.datetime.utcnow()
         self.last_checked_ok = None
         self.last_checker_status = None
         self.timeout = string_to_delta(config["timeout"])
@@ -489,10 +485,7 @@
         self.checker = None
         self.checker_initiator_tag = None
         self.disable_initiator_tag = None
-        if self.enabled:
-            self.expires = datetime.datetime.utcnow() + self.timeout
-        else:
-            self.expires = None
+        self.expires = datetime.datetime.utcnow() + self.timeout
         self.checker_callback_tag = None
         self.checker_command = config["checker"]
         self.current_checker_command = None
@@ -1285,7 +1278,7 @@
     # Created - property
     @dbus_service_property(_interface, signature="s", access="read")
     def Created_dbus_property(self):
-        return datetime_to_dbus(self.created)
+        return dbus.String(datetime_to_dbus(self.created))
     
     # LastEnabled - property
     @dbus_service_property(_interface, signature="s", access="read")
@@ -1367,12 +1360,11 @@
         self.interval = datetime.timedelta(0, 0, 0, value)
         if getattr(self, "checker_initiator_tag", None) is None:
             return
-        if self.enabled:
-            # Reschedule checker run
-            gobject.source_remove(self.checker_initiator_tag)
-            self.checker_initiator_tag = (gobject.timeout_add
-                                          (value, self.start_checker))
-            self.start_checker()    # Start one now, too
+        # Reschedule checker run
+        gobject.source_remove(self.checker_initiator_tag)
+        self.checker_initiator_tag = (gobject.timeout_add
+                                      (value, self.start_checker))
+        self.start_checker()    # Start one now, too
     
     # Checker - property
     @dbus_service_property(_interface, signature="s",
@@ -2185,9 +2177,6 @@
         "approved_by_default":
             lambda section:
             client_config.getboolean(section, "approved_by_default"),
-        "enabled":
-            lambda section:
-            client_config.getboolean(section, "enabled"),
         }
     # Construct a new dict of client settings of this form:
     # { client_name: {setting_name: value, ...}, ...}
@@ -2218,7 +2207,7 @@
             if e.errno != errno.ENOENT:
                 raise
     
-    with PGPEngine() as pgp:
+    with Crypto() as crypt:
         for client in clients_data:
             client_name = client["name"]
             
@@ -2284,11 +2273,11 @@
             
             try:
                 tcp_server.clients[client_name].secret = (
-                    pgp.decrypt(tcp_server.clients[client_name]
-                                .encrypted_secret,
-                                client_settings[client_name]
-                                ["secret"]))
-            except PGPError:
+                    crypt.decrypt(tcp_server.clients[client_name]
+                                  .encrypted_secret,
+                                  client_settings[client_name]
+                                  ["secret"]))
+            except CryptoError:
                 # If decryption fails, we use secret from new settings
                 tcp_server.clients[client_name].secret = (
                     client_settings[client_name]["secret"])
@@ -2395,11 +2384,11 @@
         # based on what config file has. If config file is
         # removed/edited, old secret will thus be unrecovable.
         clients = []
-        with PGPEngine() as pgp:
+        with Crypto() as crypt:
             for client in tcp_server.clients.itervalues():
                 key = client_settings[client.name]["secret"]
-                client.encrypted_secret = pgp.encrypt(client.secret,
-                                                      key)
+                client.encrypted_secret = crypt.encrypt(client.secret,
+                                                        key)
                 client_dict = {}
                 
                 # A list of attributes that will not be stored when

=== modified file 'mandos-clients.conf.xml'
--- mandos-clients.conf.xml	2011-11-26 23:08:17 +0000
+++ mandos-clients.conf.xml	2011-10-10 20:29:58 +0000
@@ -3,7 +3,7 @@
 	"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd" [
 <!ENTITY CONFNAME "mandos-clients.conf">
 <!ENTITY CONFPATH "<filename>/etc/mandos/clients.conf</filename>">
-<!ENTITY TIMESTAMP "2011-11-26">
+<!ENTITY TIMESTAMP "2011-10-10">
 <!ENTITY % common SYSTEM "common.ent">
 %common;
 ]>
@@ -344,20 +344,6 @@
 	</listitem>
       </varlistentry>
       
-      <varlistentry>
-	<term><option>enabled<literal> = </literal>{ <literal
-	>1</literal> | <literal>yes</literal> |	<literal>true</literal
-	> | <literal >on</literal> | <literal>0</literal> | <literal
-	>no</literal> | <literal>false</literal> | <literal
-	>off</literal> }</option></term>
-	<listitem>
-	  <para>
-	    Whether this client should be enabled by default.  The
-	    default is <quote>true</quote>.
-	  </para>
-	</listitem>
-      </varlistentry>
-      
     </variablelist>
   </refsect1>
   

